@@ -10,12 +10,12 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main.cpp" line="47"/>
-        <source>Deepin Picker is a fast screen color picking tool. RGB and HEX code can be obtained according color picked and auto saved to clipboard. The color picking area is where mouse clicked.</source>
-        <translation>ዲፕኢን መምረጫ ፈጣን የ መመልከቻ ቀለም መምረጫ መሳሪያ ነው: RGB እና HEX ኮድ ማግኘት ይቻላል እንደ ቀለም ምርጫው አይነት:  እና በራሱ ያስቀምጣል ወደ ቁራጭ ሰሌዳ ውስጥ:የ ቀለም መምረጫ ቦታ ላይ ነው አይጡን መጫን ያለብዎት</translation>
+        <location filename="../src/main.cpp" line="50"/>
+        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="69"/>
+        <location filename="../src/main.cpp" line="72"/>
         <source>Deepin Picker</source>
         <translation>ዲፕኢን መምረጫ</translation>
     </message>
