@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="ar_EG">
 <context>
     <name>Clipboard</name>
     <message>
@@ -10,14 +12,14 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main.cpp" line="50"/>
+        <location filename="../src/main.cpp" line="58"/>
         <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
         <translation>منتقي الألوان لديبين هى أداة سريعة لإنتقاء الألوان على الشاشة ، ترميزات الألوان RGB و HEX  ، يمكن الحصول عليها بالنقر و تحفظ تلقائياً فى الحافظة .</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="72"/>
+        <location filename="../src/main.cpp" line="80"/>
         <source>Deepin Picker</source>
         <translation>منتقي الألوان ديبين</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
