@@ -4,6 +4,7 @@
 <context>
     <name>Clipboard</name>
     <message>
+        <location filename="../src/clipboard.cpp" line="79"/>
         <source>Copy color %1 to clipboard</source>
         <translation type="unfinished"></translation>
     </message>
@@ -11,11 +12,13 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <source>Deepin Picker</source>
+        <location filename="../src/main.cpp" line="58"/>
+        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Deepin Picker is a fast screen color picking tool. RGB and HEX code can be obtained according color picked and auto saved to clipboard. The color picking area is where mouse clicked.</source>
+        <location filename="../src/main.cpp" line="80"/>
+        <source>Deepin Picker</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
