@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="es_419">
 <context>
     <name>Clipboard</name>
     <message>
@@ -10,14 +12,14 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main.cpp" line="50"/>
+        <location filename="../src/main.cpp" line="58"/>
         <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
         <translation>Deepin Picker es una herramienta  veloz para seleccionar un color en pantalla activa. Se puede obtener códigos RGB y HEX de acuerdo al color seleccionado y se guarda automáticamente en el portapapeles. La zona de selección de color es en donde se hace clic al ratón.</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="72"/>
+        <location filename="../src/main.cpp" line="80"/>
         <source>Deepin Picker</source>
         <translation>Selector de color Deepin Picker</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
