@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="it_IT">
 <context>
     <name>Clipboard</name>
     <message>
@@ -10,15 +12,15 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main.cpp" line="50"/>
+        <location filename="../src/main.cpp" line="58"/>
         <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
         <translation>Deepin Picker è un tool per rilevare i colori. I codici RGB e HEX del colore selezionato vengono rilevati e salvati negli appunti.
-Localizzazione italiana a cura di Massimo A. Carofano</translation>
+Localizzazione italiana a cura di Massimo A. Carofano.</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="72"/>
+        <location filename="../src/main.cpp" line="80"/>
         <source>Deepin Picker</source>
         <translation>Deepin Picker</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
