@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="pt_BR">
 <context>
     <name>Clipboard</name>
     <message>
@@ -10,14 +12,14 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main.cpp" line="50"/>
+        <location filename="../src/main.cpp" line="58"/>
         <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
         <translation>O Selecionador Deepin é uma ferramenta fácil e rápida para capturar cores na tela. Códigos RGB e HEX são obtidos com um clique e salvos automaticamente para a área de transferência.</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="72"/>
+        <location filename="../src/main.cpp" line="80"/>
         <source>Deepin Picker</source>
         <translation>Selecionador Deepin</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
